@@ -35,7 +35,7 @@ extern "C" {
 
 #define ONIGURUMA
 #define ONIGURUMA_VERSION_MAJOR   5
-#define ONIGURUMA_VERSION_MINOR   2
+#define ONIGURUMA_VERSION_MINOR   5
 #define ONIGURUMA_VERSION_TEENY   0
 
 #ifdef __cplusplus
@@ -101,12 +101,12 @@ typedef unsigned int OnigCaseFoldType;
 
 ONIG_EXTERN OnigCaseFoldType OnigDefaultCaseFoldFlag;
 
-#define ONIGENC_CASE_FOLD_MIN                    0
 /* #define ONIGENC_CASE_FOLD_HIRAGANA_KATAKANA  (1<<1) */
 /* #define ONIGENC_CASE_FOLD_KATAKANA_WIDTH     (1<<2) */
-#define ONIGENC_CASE_FOLD_MULTI_CHAR            (1<<30)
+#define ONIGENC_CASE_FOLD_TURKISH_AZERI         (1<<20)
+#define INTERNAL_ONIGENC_CASE_FOLD_MULTI_CHAR   (1<<30)
 
-#define ONIGENC_CASE_FOLD_FULL     ONIGENC_CASE_FOLD_MULTI_CHAR
+#define ONIGENC_CASE_FOLD_MIN      INTERNAL_ONIGENC_CASE_FOLD_MULTI_CHAR
 #define ONIGENC_CASE_FOLD_DEFAULT  OnigDefaultCaseFoldFlag
 
 
