@@ -676,12 +676,11 @@ onigenc_mbn_mbc_case_fold(OnigEncoding enc, OnigCaseFoldType flag,
     return 1;
   }
   else {
+    int i;
+
     len = enc_len(enc, p);
-    if (lower != p) {
-      int i;
-      for (i = 0; i < len; i++) {
-	*lower++ = *p++;
-      }
+    for (i = 0; i < len; i++) {
+      *lower++ = *p++;
     }
     (*pp) += len;
     return len; /* return byte length of converted to lower char */
@@ -843,3 +842,67 @@ onigenc_with_ascii_strncmp(OnigEncoding enc, const UChar* p, const UChar* end,
   }
   return 0;
 }
+
+/* Property management */
+static int
+resize_property_list(int new_size, const OnigCodePoint*** plist, int* psize)
+{
+  int size;
+  const OnigCodePoint **list = *plist;
+
+  size = sizeof(OnigCodePoint*) * new_size;
+  if (IS_NULL(list)) {
+    list = (const OnigCodePoint** )xmalloc(size);
+  }
+  else {
+    list = (const OnigCodePoint** )xrealloc((void* )list, size);
+  }
+
+  if (IS_NULL(list)) return ONIGERR_MEMORY;
+
+  *plist = list;
+  *psize = new_size;
+
+  return 0;
+}
+
+extern int
+onigenc_property_list_add_property(UChar* name, const OnigCodePoint* prop,
+     hash_table_type **table, const OnigCodePoint*** plist, int *pnum,
+     int *psize)
+{
+#define PROP_INIT_SIZE     16
+
+  int r;
+
+  if (*psize <= *pnum) {
+    int new_size = (*psize == 0 ? PROP_INIT_SIZE : *psize * 2);
+    r = resize_property_list(new_size, plist, psize);
+    if (r != 0) return r;
+  }
+
+  (*plist)[*pnum] = prop;
+
+  if (ONIG_IS_NULL(*table)) {
+    *table = onig_st_init_strend_table_with_size(PROP_INIT_SIZE);
+    if (ONIG_IS_NULL(*table)) return ONIGERR_MEMORY;
+  }
+
+  *pnum = *pnum + 1;
+  onig_st_insert_strend(*table, name, name + strlen((char* )name),
+			(hash_data_type )(*pnum + ONIGENC_MAX_STD_CTYPE));
+  return 0;
+}
+
+extern int
+onigenc_property_list_init(int (*f)())
+{
+  int r;
+
+  THREAD_ATOMIC_START;
+
+  r = f();
+
+  THREAD_ATOMIC_END;
+  return r;
+}
